@@ -13,6 +13,7 @@ use Exception;
 use Piwik\Access\CapabilitiesProvider;
 use Piwik\API\Request;
 use Piwik\Access\RolesProvider;
+use Piwik\Request\AuthenticationToken;
 use Piwik\Container\StaticContainer;
 use Piwik\Plugins\SitesManager\API as SitesManagerApi;
 use Piwik\Session\SessionAuth;
@@ -158,15 +159,14 @@ class Access
 
         $result = null;
 
-        $forceApiSessionPost = Common::getRequestVar('force_api_session', 0, 'int', $_POST);
-        $forceApiSessionGet = Common::getRequestVar('force_api_session', 0, 'int', $_GET);
         $isApiRequest = Piwik::getModule() === 'API' && (Piwik::getAction() === 'index' || !Piwik::getAction());
         $apiMethod = Request::getMethodIfApiRequest(null);
         $isGetApiRequest = !empty($apiMethod) && 1 === substr_count($apiMethod, '.') && strpos($apiMethod, '.get') > 0;
 
-        if (($forceApiSessionPost && $isApiRequest) || ($forceApiSessionGet && $isApiRequest && $isGetApiRequest)) {
-            $request = ($forceApiSessionGet && $isApiRequest && $isGetApiRequest) ? $_GET : $_POST;
-            $tokenAuth = Common::getRequestVar('token_auth', '', 'string', $request);
+        $token = StaticContainer::get(AuthenticationToken::class);
+
+        if ($isApiRequest && $token->isSessionToken() && ($token->wasTokenAuthProvidedSecurely() || $isGetApiRequest)) {
+            $tokenAuth = $token->getAuthToken();
             Session::start();
             $auth = StaticContainer::get(SessionAuth::class);
             $auth->setTokenAuth($tokenAuth);
@@ -218,8 +218,8 @@ class Access
         $access    = Common::prefixTable('access');
         $siteTable = Common::prefixTable('site');
 
-        return "SELECT " . $select . " FROM " . $access . " as t1
-				JOIN " . $siteTable . " as t2 USING (idsite) WHERE login = ?";
+        return "SELECT " . $select . " FROM `" . $access . "` as t1
+				JOIN `" . $siteTable . "` as t2 USING (idsite) WHERE login = ?";
     }
 
     /**
