@@ -11,6 +11,7 @@ namespace Piwik\Access\Role;
 
 use Piwik\Access\Role;
 use Piwik\Piwik;
+use Piwik\Url;
 
 class Write extends Role
 {
@@ -33,6 +34,6 @@ class Write extends Role
 
     public function getHelpUrl(): string
     {
-        return 'https://matomo.org/faq/general/faq_26910';
+        return Url::addCampaignParametersToMatomoLink('https://matomo.org/faq/general/faq_26910');
     }
 }
