@@ -12,6 +12,7 @@ namespace Piwik\ArchiveProcessor;
 use Piwik\Archive\ArchiveInvalidator;
 use Piwik\ArchiveProcessor;
 use Piwik\Cache;
+use Piwik\CacheId;
 use Piwik\Common;
 use Piwik\Config;
 use Piwik\Container\StaticContainer;
@@ -136,7 +137,7 @@ class Loader
         if (sizeof($data) == 2) {
             return $data;
         }
-        list($idArchives, $visits, $visitsConverted, $foundRecords) = $data;
+        [$idArchives, $visits, $visitsConverted, $foundRecords] = $data;
 
         // only lock meet those conditions
         if (ArchiveProcessor::$isRootArchivingRequest && !SettingsServer::isArchivePhpTriggered()) {
@@ -155,7 +156,7 @@ class Loader
                     return $data;
                 }
 
-                list($idArchives, $visits, $visitsConverted, $foundRecords) = $data;
+                [$idArchives, $visits, $visitsConverted, $foundRecords] = $data;
 
                 return $this->insertArchiveData($visits, $visitsConverted, $idArchives, $foundRecords);
             } finally {
@@ -170,7 +171,7 @@ class Loader
     /**
      * @param $visits
      * @param $visitsConverted
-     * @return array|false[]
+     * @return int[]
      */
     protected function insertArchiveData($visits, $visitsConverted, $existingArchives, $foundRecords)
     {
@@ -182,21 +183,15 @@ class Loader
             $this->params->setFoundRequestedReports($foundRecords);
         }
 
-        list($visits, $visitsConverted) = $this->prepareCoreMetricsArchive($visits, $visitsConverted);
-        list($idArchive, $visits) = $this->prepareAllPluginsArchive($visits, $visitsConverted);
+        [$visits, $visitsConverted] = $this->prepareCoreMetricsArchive($visits, $visitsConverted);
+        [$idArchive, $visits] = $this->prepareAllPluginsArchive($visits, $visitsConverted);
+        $idArchivesToQuery = [$idArchive];
 
-        if (
-            $this->isThereSomeVisits($visits)
-            || PluginsArchiver::doesAnyPluginArchiveWithoutVisits()
-        ) {
-            $idArchivesToQuery = [$idArchive];
-            if (!empty($foundRecords)) {
-                $idArchivesToQuery = array_merge($idArchivesToQuery, $existingArchives ?: []);
-            }
-            return [$idArchivesToQuery, $visits];
+        if (!empty($foundRecords)) {
+            $idArchivesToQuery = array_merge($idArchivesToQuery, $existingArchives ?: []);
         }
 
-        return [false, false];
+        return [$idArchivesToQuery, $visits];
     }
 
     /**
@@ -259,6 +254,11 @@ class Loader
             }
         }
 
+        if (self::$archivingDepth > 1) {
+            $this->logger->debug(sprintf("Sub-period archive requires processing. Archiving depth: %d", self::$archivingDepth));
+            $this->params->logStatusDebug();
+        }
+
         return [$idArchives, $visits, $visitsConverted, $existingArchives];
     }
 
@@ -276,11 +276,9 @@ class Loader
         if ($createSeparateArchiveForCoreMetrics) {
             $requestedPlugin = $this->params->getRequestedPlugin();
             $requestedReport = $this->params->getArchiveOnlyReport();
-            $isPartialArchive = $this->params->isPartialArchive();
 
             $this->params->setRequestedPlugin('VisitsSummary');
             $this->params->setArchiveOnlyReport(null);
-            $this->params->setIsPartialArchive(false);
 
             $metrics = Context::executeWithQueryParameters(['requestedReport' => ''], function () {
                 $pluginsArchiver = new PluginsArchiver($this->params);
@@ -291,7 +289,6 @@ class Loader
 
             $this->params->setRequestedPlugin($requestedPlugin);
             $this->params->setArchiveOnlyReport($requestedReport);
-            $this->params->setIsPartialArchive($isPartialArchive);
 
             $visits = $metrics['nb_visits'];
             $visitsConverted = $metrics['nb_visits_converted'];
@@ -424,19 +421,18 @@ class Loader
 
     private function getIdSitesToArchiveWhenNoVisits()
     {
-        $cache = Cache::getTransientCache();
         $cacheKey = 'Archiving.getIdSitesToArchiveWhenNoVisits';
 
-        if (!$cache->contains($cacheKey)) {
+        if (!$this->cache->contains($cacheKey)) {
             $idSites = array();
 
             // leaving undocumented unless decided otherwise
             Piwik::postEvent('Archiving.getIdSitesToArchiveWhenNoVisits', array(&$idSites));
 
-            $cache->save($cacheKey, $idSites);
+            $this->cache->save($cacheKey, $idSites);
         }
 
-        return $cache->fetch($cacheKey);
+        return $this->cache->fetch($cacheKey);
     }
 
     // public for tests
@@ -484,6 +480,16 @@ class Loader
     }
 
     public function canSkipThisArchive()
+    {
+        return $this->canSkipThisArchiveWithReason()[0];
+    }
+
+    /**
+     * @internal
+     *
+     * @return array{0: bool, 1: string}
+     */
+    public function canSkipThisArchiveWithReason(): array
     {
         $params = $this->params;
         $idSite = $params->getSite()->getId();
@@ -491,28 +497,77 @@ class Loader
         $isWebsiteUsingTracker = $this->isWebsiteUsingTheTracker($idSite);
         $isArchivingForcedWhenNoVisits = $this->shouldArchiveForSiteEvenWhenNoVisits();
         $hasSiteVisitsBetweenTimeframe = $this->hasSiteVisitsBetweenTimeframe($idSite, $params->getPeriod());
-        $hasChildArchivesInPeriod = $this->dataAccessModel->hasChildArchivesInPeriod($idSite, $params->getPeriod());
+        $hasChildArchivesInPeriod = $this->hasChildArchivesInPeriod($idSite, $params->getPeriod());
 
-        if ($this->canSkipArchiveForSegment()) {
-            return true;
+        $canSkipArchiveForSegment = $this->canSkipArchiveForSegmentWithReason();
+
+        if ($canSkipArchiveForSegment[0]) {
+            return [
+                true,
+                'Skip archive for segment: ' . $canSkipArchiveForSegment[1],
+            ];
         }
 
-        return $isWebsiteUsingTracker
-            && !$isArchivingForcedWhenNoVisits
-            && !$hasSiteVisitsBetweenTimeframe
-            && !$hasChildArchivesInPeriod;
+        if (!$isWebsiteUsingTracker) {
+            return [
+                false,
+                'Site is not using the JavaScript tracker',
+            ];
+        }
+
+        if ($isArchivingForcedWhenNoVisits) {
+            return [
+                false,
+                'Archiving is forced when no visits',
+            ];
+        }
+
+        if ($hasSiteVisitsBetweenTimeframe) {
+            return [
+                false,
+                'Site has visits between start and end date',
+            ];
+        }
+
+        if ($hasChildArchivesInPeriod) {
+            return [
+                false,
+                'There are child archives in the period',
+            ];
+        }
+
+        return [
+            true,
+            'Site is using tracker & archiving is not forced when no visits & site has has no visits between start and end date & there are no child archives in the period',
+        ];
     }
 
-    public function canSkipArchiveForSegment()
+    private function hasChildArchivesInPeriod($idSite, Period $period): bool
+    {
+        $cacheKey = CacheId::siteAware('Archiving.hasChildArchivesInPeriod.' . $period->getRangeString(), [$idSite]);
+
+        if ($this->cache->contains($cacheKey)) {
+            $hasChildArchivesInPeriod = $this->cache->fetch($cacheKey);
+        } else {
+            $hasChildArchivesInPeriod = $this->dataAccessModel->hasChildArchivesInPeriod($idSite, $period);
+            $this->cache->save($cacheKey, $hasChildArchivesInPeriod);
+        }
+        return $hasChildArchivesInPeriod;
+    }
+
+    /**
+     * @return array{0: bool, 1: string}
+     */
+    private function canSkipArchiveForSegmentWithReason(): array
     {
         $params = $this->params;
 
         if ($params->getSegment()->isEmpty()) {
-            return false;
+            return [false, 'Segment is empty'];
         }
 
         if (!empty($params->getRequestedPlugin()) && Rules::isSegmentPluginArchivingDisabled($params->getRequestedPlugin(), $params->getSite()->getId())) {
-            return true;
+            return [true, 'Plugin provided and segment plugin archiving disabled'];
         }
 
         // For better understanding of the next check please have a look at Rules::shouldProcessReportsAllPlugins implementation
@@ -523,7 +578,7 @@ class Loader
         //  - we don't have a segment that should be preprocessed
         //  - we are not forcing a single plugin archiving
         if (!Rules::shouldProcessReportsAllPlugins($params->getIdSites(), $params->getSegment(), $params->getPeriod()->getLabel())) {
-            return false;
+            return [false, 'shouldProcessReportsAllPlugins reported false'];
         }
 
         /** @var SegmentArchiving */
@@ -531,7 +586,7 @@ class Loader
         $segmentInfo = $segmentArchiving->findSegmentForHash($params->getSegment()->getHash(), $params->getSite()->getId());
 
         if (!$segmentInfo) {
-            return false;
+            return [false, 'segment not found for hash'];
         }
 
         $segmentArchiveStartDate = $segmentArchiving->getReArchiveSegmentStartDate($segmentInfo);
@@ -548,10 +603,21 @@ class Loader
             // if we have invalidations for the period and name, but only for a specific reports, we can skip
             // if the report is not null we only want to rearchive if we have invalidation for that report
             // if we don't find invalidation for that report, we can skip
-            return !$this->dataAccessModel->hasInvalidationForPeriodAndName($params->getSite()->getId(), $params->getPeriod(), $doneFlag, $params->getArchiveOnlyReport());
+            $hasInvalidationsForPeriodAndName = $this->dataAccessModel->hasInvalidationForPeriodAndName($params->getSite()->getId(), $params->getPeriod(), $doneFlag, $params->getArchiveOnlyReport());
+
+            if ($hasInvalidationsForPeriodAndName) {
+                return [false, 'Has invalidations for period and name'];
+            } else {
+                return [true, 'No invalidations for period and name'];
+            }
         }
 
-        return false;
+        return [false, 'Segment archive date set or segment archive start date is earlier than period end of day'];
+    }
+
+    public function canSkipArchiveForSegment()
+    {
+        return $this->canSkipArchiveForSegmentWithReason()[0];
     }
 
     private function isWebsiteUsingTheTracker($idSite)
@@ -591,12 +657,37 @@ class Loader
         return $idSitesNotUsingTracker;
     }
 
-    private function hasSiteVisitsBetweenTimeframe($idSite, Period $period)
+    private function hasSiteVisitsBetweenTimeframe($idSite, Period $period): bool
     {
-        $timezone = Site::getTimezoneFor($idSite);
-        list($date1, $date2) = $period->getBoundsInTimezone($timezone);
+        $cacheKeyStr = 'Archiving.hasSiteVisitsBetweenTimeframe.%s.%s';
+        $cacheKey = CacheId::siteAware(sprintf($cacheKeyStr, $period->getLabel(), $period->getRangeString()), [$idSite]);
 
-        return $this->rawLogDao->hasSiteVisitsBetweenTimeframe($date1->getDatetime(), $date2->getDatetime(), $idSite);
+        if ($this->cache->contains($cacheKey)) {
+            return $this->cache->fetch($cacheKey);
+        }
+
+        $timezone = Site::getTimezoneFor($idSite);
+        /** @var Date $date1 */
+        /** @var Date $date2 */
+        [$date1, $date2] = $period->getBoundsInTimezone($timezone);
+
+        $hasSiteVisitsBetweenTimeframe = $this->rawLogDao->hasSiteVisitsBetweenTimeframe($date1->getDatetime(), $date2->getDatetime(), $idSite);
+        $this->cache->save($cacheKey, $hasSiteVisitsBetweenTimeframe);
+
+        if ($hasSiteVisitsBetweenTimeframe) {
+            $currentPeriod = $period;
+            do {
+                $parentPeriodLabel = $currentPeriod->getParentPeriodLabel();
+                if ($parentPeriodLabel) {
+                    $parentPeriod = Period\Factory::build($parentPeriodLabel, $date1);
+                    $cacheKey = CacheId::siteAware(sprintf($cacheKeyStr, $parentPeriod->getLabel(), $parentPeriod->getRangeString()), [$idSite]);
+                    $this->cache->save($cacheKey, true);
+                    $currentPeriod = $parentPeriod;
+                }
+            } while ($parentPeriodLabel);
+        }
+
+        return $hasSiteVisitsBetweenTimeframe;
     }
 
     public static function getArchivingDepth()
