@@ -242,7 +242,7 @@ class LogAggregator
     {
         try {
             // using DROP TABLE IF EXISTS would not work on a DB reader if the table doesn't exist...
-            $this->getDb()->fetchOne('SELECT /* WP IGNORE ERROR */ 1 FROM ' . $segmentTablePrefixed . ' LIMIT 1');
+            $this->getDb()->fetchOne('SELECT /* WP IGNORE ERROR */ 1 FROM `' . $segmentTablePrefixed . '` LIMIT 1');
             $tableExists = true;
         } catch (\Exception $e) {
             $tableExists = false;
@@ -339,12 +339,13 @@ class LogAggregator
      * @param             $orderBy
      * @param int         $limit
      * @param int         $offset
+     * @param bool        $withRollup
      *
      * @return array|mixed|string
      * @throws \Piwik\Exception\DI\DependencyException
      * @throws \Piwik\Exception\DI\NotFoundException
      */
-    public function generateQuery($select, $from, $where, $groupBy, $orderBy, $limit = 0, $offset = 0)
+    public function generateQuery($select, $from, $where, $groupBy, $orderBy, $limit = 0, $offset = 0, bool $withRollup = false)
     {
         $segment = $this->segment;
         $bind = $this->getGeneralQueryBindParams();
@@ -393,7 +394,7 @@ class LogAggregator
             }
         }
 
-        $query = $segment->getSelectQuery($select, $from, $where, $bind, $orderBy, $groupBy, $limit, $offset);
+        $query = $segment->getSelectQuery($select, $from, $where, $bind, $orderBy, $groupBy, $limit, $offset, $forceGroupBy = false, $withRollup);
 
         if (is_array($query) && array_key_exists('sql', $query)) {
             $query['sql'] = DbHelper::addOriginHintToQuery($query['sql'], $this->queryOriginHint, $this->dateStart, $this->dateEnd, $this->sites, $this->segment);
@@ -888,7 +889,7 @@ class LogAggregator
     {
         $bind = [
             $this->dateStart->toString(Date::DATE_TIME_FORMAT),
-            $this->dateEnd->toString(Date::DATE_TIME_FORMAT)
+            $this->dateEnd->toString(Date::DATE_TIME_FORMAT),
         ];
         return array_merge($bind, $this->sites);
     }
@@ -961,7 +962,7 @@ class LogAggregator
                         'CASE log_conversion_item.idorder WHEN \'0\' THEN %d ELSE %d END AS ecommerceType',
                         GoalManager::IDGOAL_CART,
                         GoalManager::IDGOAL_ORDER
-                    )
+                    ),
                 )
             ),
             // FROM ...
@@ -969,8 +970,8 @@ class LogAggregator
                 "log_conversion_item",
                 array(
                     "table" => "log_action",
-                    "joinOn" => sprintf("log_conversion_item.%s = log_action.idaction", $dimension)
-                )
+                    "joinOn" => sprintf("log_conversion_item.%s = log_action.idaction", $dimension),
+                ),
             ),
             // WHERE ... AND ...
             implode(
@@ -979,7 +980,7 @@ class LogAggregator
                     'log_conversion_item.server_time >= ?',
                     'log_conversion_item.server_time <= ?',
                     'log_conversion_item.idsite IN (' . Common::getSqlStringFieldsArray($this->sites) . ')',
-                    'log_conversion_item.deleted = 0'
+                    'log_conversion_item.deleted = 0',
                 )
             ),
             // GROUP BY ...
@@ -1081,7 +1082,7 @@ class LogAggregator
                 $from[] = array(
                     'table'      => 'log_action',
                     'tableAlias' => $tableAlias,
-                    'joinOn'     => $joinOn
+                    'joinOn'     => $joinOn,
                 );
             }
         }
@@ -1253,7 +1254,7 @@ class LogAggregator
                 ['table' => 'log_link_visit_action', 'tableAlias' => 'logva', 'join' => 'RIGHT JOIN',
                             'joinOn' => 'log_conversion.idvisit = logva.idvisit'],
                 ['table' => 'log_action', 'tableAlias' => 'lac',
-                            'joinOn' => 'logva.' . $linkField . ' = lac.idaction']
+                            'joinOn' => 'logva.' . $linkField . ' = lac.idaction'],
         ];
 
         $where = $this->getWhereStatement('log_conversion', 'server_time');
@@ -1297,7 +1298,7 @@ class LogAggregator
                     sprintf('%s AS `%d`', self::getSqlRevenue('SUM(log_conversion.revenue_shipping)'), Metrics::INDEX_GOAL_ECOMMERCE_REVENUE_SHIPPING),
                     sprintf('%s AS `%d`', self::getSqlRevenue('SUM(log_conversion.revenue_discount)'), Metrics::INDEX_GOAL_ECOMMERCE_REVENUE_DISCOUNT),
                     sprintf('SUM(log_conversion.items) AS `%d`', Metrics::INDEX_GOAL_ECOMMERCE_ITEMS),
-                    sprintf('COUNT(*) AS `%d`', Metrics::INDEX_GOAL_NB_CONVERSIONS_ENTRY)
+                    sprintf('COUNT(*) AS `%d`', Metrics::INDEX_GOAL_NB_CONVERSIONS_ENTRY),
                 ]
         );
 
@@ -1305,12 +1306,12 @@ class LogAggregator
             $tableName,
                 [
                     "table"  => "log_visit",
-                    "joinOn" => "log_visit.idvisit = log_conversion.idvisit"
+                    "joinOn" => "log_visit.idvisit = log_conversion.idvisit",
                 ],
                 [
                     "table" => "log_action",
-                    "joinOn" => "log_action.idaction = log_visit." . $linkField
-                ]
+                    "joinOn" => "log_action.idaction = log_visit." . $linkField,
+                ],
         ];
 
         $where   = $linkField . ' IS NOT NULL AND log_conversion.idgoal >= 0';
