@@ -34,7 +34,11 @@ abstract class Renderer extends BaseFactory
      */
     protected $exception;
     protected $renderSubTables = false;
+
+    /** @var bool */
     protected $hideIdSubDatatable = false;
+    /** @var bool */
+    protected $hideMetadata = false;
 
     /**
      * Whether to translate column names (i.e. metric names) or not
@@ -44,15 +48,15 @@ abstract class Renderer extends BaseFactory
 
     /**
      * Column translations
-     * @var array
+     * @var null|array
      */
-    private $columnTranslations = false;
+    private $columnTranslations = null;
 
     /**
      * The API method that has returned the data that should be rendered
-     * @var string
+     * @var null|string
      */
-    public $apiMethod = false;
+    public $apiMethod = null;
 
     /**
      * API metadata for the current report
@@ -75,17 +79,25 @@ abstract class Renderer extends BaseFactory
      *
      * @param bool $enableRenderSubTable
      */
-    public function setRenderSubTables($enableRenderSubTable)
+    public function setRenderSubTables(bool $enableRenderSubTable): void
     {
-        $this->renderSubTables = (bool)$enableRenderSubTable;
+        $this->renderSubTables = $enableRenderSubTable;
     }
 
     /**
-     * @param bool $bool
+     * @param bool $hideIdSubDataTable
      */
-    public function setHideIdSubDatableFromResponse($bool)
+    public function setHideIdSubDatableFromResponse(bool $hideIdSubDataTable): void
     {
-        $this->hideIdSubDatatable = (bool)$bool;
+        $this->hideIdSubDatatable = $hideIdSubDataTable;
+    }
+
+    /**
+     * @param bool $hideMetadata
+     */
+    public function setHideMetadataFromResponse(bool $hideMetadata): void
+    {
+        $this->hideMetadata = $hideMetadata;
     }
 
     /**
@@ -93,7 +105,7 @@ abstract class Renderer extends BaseFactory
      *
      * @return bool
      */
-    protected function isRenderSubtables()
+    protected function isRenderSubtables(): bool
     {
         return $this->renderSubTables;
     }
@@ -117,7 +129,7 @@ abstract class Renderer extends BaseFactory
      * @see render()
      * @return string
      */
-    public function __toString()
+    public function __toString(): string
     {
         return $this->render();
     }
@@ -146,7 +158,7 @@ abstract class Renderer extends BaseFactory
                                                  'json',
                                                  'csv',
                                                  'tsv',
-                                                 'html'
+                                                 'html',
     );
 
     /**
@@ -205,7 +217,7 @@ abstract class Renderer extends BaseFactory
                 "&aacute;", "&acirc;", "&atilde;", "&auml;", "&aring;", "&aelig;", "&ccedil;", "&egrave;", "&eacute;",
                 "&ecirc;", "&euml;", "&igrave;", "&iacute;", "&icirc;", "&iuml;", "&eth;", "&ntilde;", "&ograve;",
                 "&oacute;", "&ocirc;", "&otilde;", "&ouml;", "&divide;", "&oslash;", "&ugrave;", "&uacute;", "&ucirc;",
-                "&uuml;", "&yacute;", "&thorn;", "&yuml;", "&euro;"
+                "&uuml;", "&yacute;", "&thorn;", "&yuml;", "&euro;",
             );
             $xmlentities  = array(
                 "&#162;", "&#163;", "&#164;", "&#165;", "&#166;", "&#167;", "&#168;", "&#169;", "&#170;", "&#171;",
@@ -217,7 +229,7 @@ abstract class Renderer extends BaseFactory
                 "&#222;", "&#223;", "&#224;", "&#225;", "&#226;", "&#227;", "&#228;", "&#229;", "&#230;", "&#231;",
                 "&#232;", "&#233;", "&#234;", "&#235;", "&#236;", "&#237;", "&#238;", "&#239;", "&#240;", "&#241;",
                 "&#242;", "&#243;", "&#244;", "&#245;", "&#246;", "&#247;", "&#248;", "&#249;", "&#250;", "&#251;",
-                "&#252;", "&#253;", "&#254;", "&#255;", "&#8364;"
+                "&#252;", "&#253;", "&#254;", "&#255;", "&#8364;",
             );
             $value        = str_replace($htmlentities, $xmlentities, $value);
         } elseif ($value === false) {
@@ -243,7 +255,7 @@ abstract class Renderer extends BaseFactory
         // load the translations only once
         // when multiple dates are requested (date=...,...&period=day), the meta data would
         // be loaded lots of times otherwise
-        if ($this->columnTranslations === false) {
+        if ($this->columnTranslations === null) {
             $meta = $this->getApiMetaData();
             if ($meta === false) {
                 return $names;
@@ -283,7 +295,7 @@ abstract class Renderer extends BaseFactory
     protected function getApiMetaData()
     {
         if ($this->apiMetaData === null) {
-            list($apiModule, $apiAction) = explode('.', $this->apiMethod);
+            [$apiModule, $apiAction] = explode('.', $this->apiMethod);
 
             if (!$apiModule || !$apiAction) {
                 $this->apiMetaData = false;
@@ -475,11 +487,11 @@ abstract class Renderer extends BaseFactory
         $array = [];
 
         foreach ($table->getRows() as $id => $row) {
-            $newRow = array(
+            $newRow = [
                 'columns'        => $row->getColumns(),
                 'metadata'       => $row->getMetadata(),
                 'idsubdatatable' => $row->getIdSubDataTable(),
-            );
+            ];
 
             if ($id == DataTable::ID_SUMMARY_ROW) {
                 $newRow['issummaryrow'] = true;
@@ -498,13 +510,14 @@ abstract class Renderer extends BaseFactory
                 $newRow['subtable'] = $subTable;
                 if (
                     $this->hideIdSubDatatable === false
+                    && $this->hideMetadata === false
                     && isset($newRow['metadata']['idsubdatatable_in_db'])
                 ) {
                     $newRow['columns']['idsubdatatable'] = $newRow['metadata']['idsubdatatable_in_db'];
                 }
                 unset($newRow['metadata']['idsubdatatable_in_db']);
             }
-            if ($this->hideIdSubDatatable !== false) {
+            if ($this->hideIdSubDatatable || $this->hideMetadata) {
                 unset($newRow['idsubdatatable']);
             }
 
@@ -548,15 +561,20 @@ abstract class Renderer extends BaseFactory
     {
         $flatArray = [];
         foreach ($array as $row) {
-            $newRow = $row['columns'] + $row['metadata'];
+            if ($this->hideMetadata) {
+                $newRow = $row['columns'];
+            } else {
+                $newRow = $row['columns'] + $row['metadata'];
+            }
+
             if (
                 isset($row['idsubdatatable'])
                 && $this->hideIdSubDatatable === false
             ) {
-                $newRow += array('idsubdatatable' => $row['idsubdatatable']);
+                $newRow += ['idsubdatatable' => $row['idsubdatatable']];
             }
             if (isset($row['subtable'])) {
-                $newRow += array('subtable' => $this->flattenArray($row['subtable']));
+                $newRow += ['subtable' => $this->flattenArray($row['subtable'])];
             }
             $flatArray[] = $newRow;
         }
