@@ -217,123 +217,121 @@ class SegmentExpression
         // self::checkFieldIsAvailable() on it.
         $innerSql = null;
 
-        if (empty($sqlExpression)) {
-            // Segment::getCleanedExpression() may return array(null, $matchType, null)
-            $operandWillNotMatchAnyRow = empty($field) && is_null($value);
-            if ($operandWillNotMatchAnyRow) {
-                if ($matchType == self::MATCH_EQUAL) {
-                    // eg. pageUrl==DoesNotExist
-                    // Equal to NULL means it will match none
-                    $sqlExpression = self::SQL_WHERE_DO_NOT_MATCH_ANY_ROW;
-                } elseif ($matchType == self::MATCH_NOT_EQUAL) {
-                    // eg. pageUrl!=DoesNotExist
-                    // Not equal to NULL means it matches all rows
-                    $sqlExpression = self::SQL_WHERE_MATCHES_ALL_ROWS;
-                } elseif (
-                    $matchType == self::MATCH_CONTAINS
-                    || $matchType == self::MATCH_DOES_NOT_CONTAIN
-                    || $matchType == self::MATCH_STARTS_WITH
-                    || $matchType == self::MATCH_ENDS_WITH
-                ) {
-                    // no action was found for CONTAINS / DOES NOT CONTAIN
-                    // eg. pageUrl=@DoesNotExist -> matches no row
-                    // eg. pageUrl!@DoesNotExist -> matches no rows
-                    $sqlExpression = self::SQL_WHERE_DO_NOT_MATCH_ANY_ROW;
-                } else {
-                    // it is not expected to reach this code path
-                    throw new Exception("Unexpected match type $matchType for your segment. " .
-                        "Please report this issue to the Matomo team with the segment you are using.");
-                }
-
-                return array($sqlExpression, $value = null);
-            }
-
-            $alsoMatchNULLValues = false;
-            switch ($matchType) {
-                case self::MATCH_EQUAL:
-                    $sqlMatch = '%s =';
-                    break;
-                case self::MATCH_NOT_EQUAL:
-                    $sqlMatch = '%s <>';
-                    $alsoMatchNULLValues = true;
-                    break;
-                case self::MATCH_GREATER:
-                    $sqlMatch = '%s >';
-                    break;
-                case self::MATCH_LESS:
-                    $sqlMatch = '%s <';
-                    break;
-                case self::MATCH_GREATER_OR_EQUAL:
-                    $sqlMatch = '%s >=';
-                    break;
-                case self::MATCH_LESS_OR_EQUAL:
-                    $sqlMatch = '%s <=';
-                    break;
-                case self::MATCH_CONTAINS:
-                    $sqlMatch = '%s LIKE';
-                    $value = '%' . $this->escapeLikeString($value) . '%';
-                    break;
-                case self::MATCH_DOES_NOT_CONTAIN:
-                    $sqlMatch = '%s NOT LIKE';
-                    $value = '%' . $this->escapeLikeString($value) . '%';
-                    $alsoMatchNULLValues = true;
-                    break;
-                case self::MATCH_STARTS_WITH:
-                    $sqlMatch = '%s LIKE';
-                    $value = $this->escapeLikeString($value) . '%';
-                    break;
-                case self::MATCH_ENDS_WITH:
-                    $sqlMatch = '%s LIKE';
-                    $value = '%' . $this->escapeLikeString($value);
-                    break;
-
-                case self::MATCH_IS_NOT_NULL_NOR_EMPTY:
-                    $sqlMatch = '%s IS NOT NULL AND %s <> \'\' AND %s <> \'0\'';
-                    $value = null;
-                    break;
-
-                case self::MATCH_IS_NULL_OR_EMPTY:
-                    $sqlMatch = '%s IS NULL OR %s = \'\' OR %s = \'0\'';
-                    $value = null;
-                    break;
-
-                case self::MATCH_ACTIONS_CONTAINS:
-                    // this match type is not accessible from the outside
-                    // (it won't be matched in self::parseSubExpressions())
-                    // it can be used internally to inject sub-expressions into the query.
-                    // see Segment::getCleanedExpression()
-                    $innerSql = $value['SQL'];
-                    $sqlMatch = '%s IN (%innerSql%)';
-                    $value = $value['bind'];
-                    break;
-                case self::MATCH_ACTIONS_NOT_CONTAINS:
-                    // this match type is not accessible from the outside
-                    // (it won't be matched in self::parseSubExpressions())
-                    // it can be used internally to inject sub-expressions into the query.
-                    // see Segment::getCleanedExpression()
-                    $innerSql = $value['sql'];
-                    $sqlMatch = '%s NOT IN (%innerSql%)';
-                    $value = $value['bind'];
-                    break;
-                default:
-                    throw new Exception("Filter contains the match type '" . $matchType . "' which is not supported");
-                    break;
-            }
-
-            // We match NULL values when rows are excluded only when we are not doing a
-            $alsoMatchNULLValues = $alsoMatchNULLValues && !empty($value);
-
-            if (
-                $matchType === self::MATCH_ACTIONS_CONTAINS || $matchType === self::MATCH_ACTIONS_NOT_CONTAINS
-                || is_null($value)
+        // Segment::getCleanedExpression() may return array(null, $matchType, null)
+        $operandWillNotMatchAnyRow = empty($field) && is_null($value);
+        if ($operandWillNotMatchAnyRow) {
+            if ($matchType == self::MATCH_EQUAL) {
+                // eg. pageUrl==DoesNotExist
+                // Equal to NULL means it will match none
+                $sqlExpression = self::SQL_WHERE_DO_NOT_MATCH_ANY_ROW;
+            } elseif ($matchType == self::MATCH_NOT_EQUAL) {
+                // eg. pageUrl!=DoesNotExist
+                // Not equal to NULL means it matches all rows
+                $sqlExpression = self::SQL_WHERE_MATCHES_ALL_ROWS;
+            } elseif (
+                $matchType == self::MATCH_CONTAINS
+                || $matchType == self::MATCH_DOES_NOT_CONTAIN
+                || $matchType == self::MATCH_STARTS_WITH
+                || $matchType == self::MATCH_ENDS_WITH
             ) {
-                $sqlExpression = "( $sqlMatch )";
+                // no action was found for CONTAINS / DOES NOT CONTAIN
+                // eg. pageUrl=@DoesNotExist -> matches no row
+                // eg. pageUrl!@DoesNotExist -> matches no rows
+                $sqlExpression = self::SQL_WHERE_DO_NOT_MATCH_ANY_ROW;
             } else {
-                if ($alsoMatchNULLValues) {
-                    $sqlExpression = "( $field IS NULL OR $sqlMatch ? )";
-                } else {
-                    $sqlExpression = "$sqlMatch ?";
-                }
+                // it is not expected to reach this code path
+                throw new Exception("Unexpected match type $matchType for your segment. " .
+                    "Please report this issue to the Matomo team with the segment you are using.");
+            }
+
+            return array($sqlExpression, $value = null);
+        }
+
+        $alsoMatchNULLValues = false;
+        switch ($matchType) {
+            case self::MATCH_EQUAL:
+                $sqlMatch = '%s =';
+                break;
+            case self::MATCH_NOT_EQUAL:
+                $sqlMatch = '%s <>';
+                $alsoMatchNULLValues = true;
+                break;
+            case self::MATCH_GREATER:
+                $sqlMatch = '%s >';
+                break;
+            case self::MATCH_LESS:
+                $sqlMatch = '%s <';
+                break;
+            case self::MATCH_GREATER_OR_EQUAL:
+                $sqlMatch = '%s >=';
+                break;
+            case self::MATCH_LESS_OR_EQUAL:
+                $sqlMatch = '%s <=';
+                break;
+            case self::MATCH_CONTAINS:
+                $sqlMatch = '%s LIKE';
+                $value = '%' . $this->escapeLikeString($value) . '%';
+                break;
+            case self::MATCH_DOES_NOT_CONTAIN:
+                $sqlMatch = '%s NOT LIKE';
+                $value = '%' . $this->escapeLikeString($value) . '%';
+                $alsoMatchNULLValues = true;
+                break;
+            case self::MATCH_STARTS_WITH:
+                $sqlMatch = '%s LIKE';
+                $value = $this->escapeLikeString($value) . '%';
+                break;
+            case self::MATCH_ENDS_WITH:
+                $sqlMatch = '%s LIKE';
+                $value = '%' . $this->escapeLikeString($value);
+                break;
+
+            case self::MATCH_IS_NOT_NULL_NOR_EMPTY:
+                $sqlMatch = '%s IS NOT NULL AND %s <> \'\' AND %s <> \'0\'';
+                $value = null;
+                break;
+
+            case self::MATCH_IS_NULL_OR_EMPTY:
+                $sqlMatch = '%s IS NULL OR %s = \'\' OR %s = \'0\'';
+                $value = null;
+                break;
+
+            case self::MATCH_ACTIONS_CONTAINS:
+                // this match type is not accessible from the outside
+                // (it won't be matched in self::parseSubExpressions())
+                // it can be used internally to inject sub-expressions into the query.
+                // see Segment::getCleanedExpression()
+                $innerSql = $value['SQL'];
+                $sqlMatch = '%s IN (%innerSql%)';
+                $value = $value['bind'];
+                break;
+            case self::MATCH_ACTIONS_NOT_CONTAINS:
+                // this match type is not accessible from the outside
+                // (it won't be matched in self::parseSubExpressions())
+                // it can be used internally to inject sub-expressions into the query.
+                // see Segment::getCleanedExpression()
+                $innerSql = $value['sql'];
+                $sqlMatch = '%s NOT IN (%innerSql%)';
+                $value = $value['bind'];
+                break;
+            default:
+                throw new Exception("Filter contains the match type '" . $matchType . "' which is not supported");
+                break;
+        }
+
+        // We match NULL values when rows are excluded only when we are not doing a
+        $alsoMatchNULLValues = $alsoMatchNULLValues && !empty($value);
+
+        if (
+            $matchType === self::MATCH_ACTIONS_CONTAINS || $matchType === self::MATCH_ACTIONS_NOT_CONTAINS
+            || is_null($value)
+        ) {
+            $sqlExpression = "( $sqlMatch )";
+        } else {
+            if ($alsoMatchNULLValues) {
+                $sqlExpression = "( $field IS NULL OR $sqlMatch ? )";
+            } else {
+                $sqlExpression = "$sqlMatch ?";
             }
         }
 
