@@ -466,7 +466,7 @@ class GoalManager
                 $itemToUpdate = array_merge(
                     $itemInDb,
                     array('deleted'                => 1,
-                          'idorder_original_value' => $itemInDbOriginal['idorder_original_value']
+                          'idorder_original_value' => $itemInDbOriginal['idorder_original_value'],
                     )
                 );
 
@@ -558,7 +558,7 @@ class GoalManager
                 self::INTERNAL_ITEM_CATEGORY4 => $category4,
                 self::INTERNAL_ITEM_CATEGORY5 => $category5,
                 self::INTERNAL_ITEM_PRICE     => $price,
-                self::INTERNAL_ITEM_QUANTITY  => $quantity
+                self::INTERNAL_ITEM_QUANTITY  => $quantity,
             );
         }
 
@@ -695,7 +695,7 @@ class GoalManager
             'idsite'             => $goal['idsite'],
             'idvisitor'          => $goal['idvisitor'],
             'server_time'        => $goal['server_time'],
-            'idvisit'            => $goal['idvisit']
+            'idvisit'            => $goal['idvisit'],
         );
         return $newRow;
     }
@@ -778,7 +778,7 @@ class GoalManager
          *
          * This event can be used to modify conversion information or to add new information to be persisted.
          *
-         * This event is deprecated, use [Dimensions](http://developer.piwik.org/guides/dimensions) instead.
+         * This event is deprecated, use [Dimensions](https://developer.matomo.org/guides/dimensions) instead.
          *
          * @param array $conversion The conversion entity. Read [this](/guides/persistence-and-the-mysql-backend#conversions)
          *                          to see what it contains.
@@ -812,10 +812,15 @@ class GoalManager
         $wasInserted = $this->getModel()->createConversion($conversion);
         if (
             !$wasInserted
-            && !empty($idorder)
         ) {
-            $idSite = $request->getIdSite();
-            throw new InvalidRequestParameterException("Invalid non-unique idsite/idorder combination ($idSite, $idorder), conversion was not inserted.");
+            if (!empty($idorder)) {
+                $idSite = $request->getIdSite();
+                throw new InvalidRequestParameterException("Invalid non-unique idsite/idorder combination ($idSite, $idorder), conversion was not inserted.");
+            } elseif ($conversion['buster'] > 0) {
+                // Note: The buster is set to 0 for goals that can only be triggered once per visit.
+                // It's expected behaviour that creating additional conversion fail, so we don't log failures in that case.
+                StaticContainer::get(LoggerInterface::class)->warning("Failed to insert goal due to duplicate idvisit/idgoal/buster combination ({$conversion['idvisit']}, {$conversion['idgoal']}, {$conversion['buster']})");
+            }
         }
 
         return $wasInserted;
