@@ -21,6 +21,7 @@ export interface AjaxOptions {
   returnResponseObject?: boolean;
   errorElement?: HTMLElement|JQuery|string;
   redirectOnSuccess?: QueryParameters|boolean;
+  abortable?: boolean;
 }
 
 interface ErrorResponse {
@@ -174,6 +175,8 @@ export default class AjaxHelper<T = any> { // eslint-disable-line
 
   abortController: AbortController|null = null;
 
+  abortable = true;
+
   defaultParams = ['idSite', 'period', 'date', 'segment'];
 
   resolveWithHelper = false;
@@ -243,6 +246,10 @@ export default class AjaxHelper<T = any> { // eslint-disable-line
       helper.resolveWithHelper = true;
     }
 
+    if (options.abortable === false) {
+      helper.abortable = false;
+    }
+
     return helper.send().then((result: R | ErrorResponse | AjaxHelper) => {
       const data = result instanceof AjaxHelper ? result.requestHandle!.responseJSON : result;
 
@@ -504,7 +511,9 @@ export default class AjaxHelper<T = any> { // eslint-disable-line
     }
 
     this.requestHandle = this.buildAjaxCall();
-    window.globalAjaxQueue.push(this.requestHandle);
+    if (this.abortable) {
+      window.globalAjaxQueue.push(this.requestHandle);
+    }
 
     if (this.abortController) {
       this.abortController.signal.addEventListener('abort', () => {
@@ -584,7 +593,9 @@ export default class AjaxHelper<T = any> { // eslint-disable-line
       complete: this.completeCallback,
       headers: this.headers ? this.headers : undefined,
       error: function errorCallback(...args: any[]) { // eslint-disable-line
-        window.globalAjaxQueue.active -= 1;
+        if (self.abortable) {
+          window.globalAjaxQueue.active -= 1;
+        }
 
         if (self.errorCallback) {
           self.errorCallback.apply(this, args);
@@ -642,7 +653,9 @@ export default class AjaxHelper<T = any> { // eslint-disable-line
           this.callback(response, status, request);
         }
 
-        window.globalAjaxQueue.active -= 1;
+        if (self.abortable) {
+          window.globalAjaxQueue.active -= 1;
+        }
         if (Matomo.ajaxRequestFinished) {
           Matomo.ajaxRequestFinished();
         }
