@@ -11,9 +11,9 @@ namespace Piwik\Plugins\ExamplePlugin;
 
 /**
  * A controller lets you for example create a page that can be added to a menu. For more information read our guide
- * http://developer.piwik.org/guides/mvc-in-piwik or have a look at the our API references for controller and view:
- * http://developer.piwik.org/api-reference/Piwik/Plugin/Controller and
- * http://developer.piwik.org/api-reference/Piwik/View
+ * https://developer.matomo.org/guides/mvc-in-piwik or have a look at the our API references for controller and view:
+ * https://developer.matomo.org/api-reference/Piwik/Plugin/Controller and
+ * https://developer.matomo.org/api-reference/Piwik/View
  */
 class Controller extends \Piwik\Plugin\Controller
 {
@@ -21,7 +21,7 @@ class Controller extends \Piwik\Plugin\Controller
     {
         // Render the Twig template templates/index.twig and assign the view variable answerToLife to the view.
         return $this->renderTemplate('index', array(
-            'answerToLife' => 42
+            'answerToLife' => 42,
         ));
     }
 }
