@@ -9,16 +9,21 @@
 
 namespace Piwik\Plugins\PrivacyManager;
 
+use Exception;
 use Piwik\API\Request;
 use Piwik\Container\StaticContainer;
 use Piwik\Piwik;
 use Piwik\Config as PiwikConfig;
 use Piwik\Plugin\Manager;
+use Piwik\Plugins\FeatureFlags\FeatureFlagManager;
 use Piwik\Plugins\Live\Live;
+use Piwik\Plugins\PrivacyManager\FeatureFlags\PrivacyCompliance;
 use Piwik\Plugins\PrivacyManager\Model\DataSubjects;
 use Piwik\Plugins\PrivacyManager\Dao\LogDataAnonymizer;
 use Piwik\Plugins\PrivacyManager\Model\LogDataAnonymizations;
 use Piwik\Plugins\PrivacyManager\Validators\VisitsDataSubject;
+use Piwik\Policy\CompliancePolicy;
+use Piwik\Policy\PolicyManager;
 use Piwik\Site;
 use Piwik\Validators\BaseValidator;
 
@@ -49,16 +54,24 @@ class API extends \Piwik\Plugin\API
      */
     private $referrerAnonymizer;
 
+    /**
+     * @var FeatureFlagManager
+     */
+    private $featureFlagManager;
+
+
     public function __construct(
         DataSubjects $gdpr,
         LogDataAnonymizations $logDataAnonymizations,
         LogDataAnonymizer $logDataAnonymizer,
-        ReferrerAnonymizer $referrerAnonymizer
+        ReferrerAnonymizer $referrerAnonymizer,
+        FeatureFlagManager $featureFlagManager
     ) {
         $this->gdpr = $gdpr;
         $this->logDataAnonymizations = $logDataAnonymizations;
         $this->logDataAnonymizer = $logDataAnonymizer;
         $this->referrerAnonymizer = $referrerAnonymizer;
+        $this->featureFlagManager = $featureFlagManager;
     }
 
     private function checkDataSubjectVisits($visits)
@@ -124,7 +137,7 @@ class API extends \Piwik\Plugin\API
             'period' => 'range',
             'date' => '1998-01-01,today',
             'filter_limit' => 401,
-            'doNotFetchActions' => 1
+            'doNotFetchActions' => 1,
         ]);
 
         $columnsToKeep = [
@@ -166,6 +179,7 @@ class API extends \Piwik\Plugin\API
         $anonymizeUserId = false,
         $unsetVisitColumns = [],
         $unsetLinkVisitActionColumns = [],
+        #[\SensitiveParameter]
         $passwordConfirmation = ''
     ) {
         Piwik::checkUserHasSuperUserAccess();
@@ -215,7 +229,7 @@ class API extends \Piwik\Plugin\API
         foreach ($columns as $column => $default) {
             $formatted[] = array(
                 'column_name' => $column,
-                'default_value' => $default
+                'default_value' => $default,
             );
         }
 
@@ -225,10 +239,24 @@ class API extends \Piwik\Plugin\API
     /**
      * @internal
      */
-    public function setAnonymizeIpSettings($anonymizeIPEnable, $maskLength, $useAnonymizedIpForVisitEnrichment, $anonymizeUserId = false, $anonymizeOrderId = false, $anonymizeReferrer = '', $forceCookielessTracking = false, $randomizeConfigId = false)
-    {
+    public function setAnonymizeIpSettings(
+        $anonymizeIPEnable,
+        $maskLength,
+        $useAnonymizedIpForVisitEnrichment,
+        $anonymizeUserId = false,
+        $anonymizeOrderId = false,
+        $anonymizeReferrer = '',
+        $forceCookielessTracking = false,
+        $randomizeConfigId = false,
+        #[\SensitiveParameter]
+        $passwordConfirmation = ''
+    ) {
         Piwik::checkUserHasSuperUserAccess();
 
+        if ($randomizeConfigId == '1') {
+            $this->confirmCurrentUserPassword($passwordConfirmation);
+        }
+
         if ($anonymizeIPEnable == '1') {
             IPAnonymizer::activate();
         } elseif ($anonymizeIPEnable == '0') {
@@ -306,7 +334,7 @@ class API extends \Piwik\Plugin\API
         $this->confirmCurrentUserPassword($passwordConfirmation);
 
         return $this->savePurgeDataSettings(array(
-            'delete_logs_schedule_lowest_interval' => (int) $deleteLowestInterval
+            'delete_logs_schedule_lowest_interval' => (int) $deleteLowestInterval,
         ));
     }
 
@@ -342,6 +370,7 @@ class API extends \Piwik\Plugin\API
         $keepYear = 0,
         $keepRange = 0,
         $keepSegments = 0,
+        #[\SensitiveParameter]
         $passwordConfirmation = ''
     ) {
         Piwik::checkUserHasSuperUserAccess();
@@ -377,8 +406,10 @@ class API extends \Piwik\Plugin\API
      *
      * @internal
      */
-    public function executeDataPurge($passwordConfirmation)
-    {
+    public function executeDataPurge(
+        #[\SensitiveParameter]
+        $passwordConfirmation
+    ) {
         $this->confirmCurrentUserPassword($passwordConfirmation);
         Piwik::checkUserHasSuperUserAccess();
 
@@ -396,6 +427,80 @@ class API extends \Piwik\Plugin\API
         }
     }
 
+    /**
+     * @internal
+     * @return array<array<string,string>>
+     */
+    public function getCompliancePolicies(): array
+    {
+        return PolicyManager::getAllPoliciesDetails();
+    }
+
+    /**
+     * @internal
+     * @param int|string $idSite
+     * @return array<string,bool|array<int, array<string,string>>>
+     */
+    public function getComplianceStatus($idSite, string $complianceType): array
+    {
+        if ($idSite === 'all') {
+            $idSite = null;
+        } else {
+            $idSite = intval($idSite);
+        }
+
+        if (false === $this->featureFlagManager->isFeatureActive(PrivacyCompliance::class)) {
+            throw new Exception('Feature not available');
+        }
+
+        Piwik::checkUserHasSuperUserAccess();
+
+        $policy = PolicyManager::getPolicyByName($complianceType);
+
+        if (is_null($policy)) {
+            throw new Exception('Invalid compliance type');
+        }
+
+        $payload['complianceModeEnforced'] = PolicyManager::isPolicyActive($policy, $idSite);
+        $settingsUnderPolicy = PolicyManager::getAllControlledSettings($policy, $idSite);
+        foreach ($settingsUnderPolicy as $setting) {
+            $payload['complianceRequirements'][] = [
+                'name' => $setting::getTitle(),
+                'value' => $setting::isCompliant($policy, $idSite) ? 'compliant' : 'non_compliant',
+                'notes' => $setting::getComplianceRequirementNote($idSite),
+            ];
+        }
+        return $payload;
+    }
+
+    /**
+     * @internal
+     */
+    public function setComplianceStatus(string $idSite, string $complianceType, bool $enforce): bool
+    {
+        if (!$this->featureFlagManager->isFeatureActive(PrivacyCompliance::class)) {
+            throw new Exception('Feature not available');
+        }
+
+        Piwik::checkUserHasSuperUserAccess();
+
+        $policy = PolicyManager::getPolicyByName($complianceType);
+
+        if (is_null($policy) || !is_a($policy, CompliancePolicy::class, true)) {
+            throw new Exception('Invalid compliance type');
+        }
+
+        if ($idSite === 'all') {
+            $idSite = null;
+        } else {
+            $idSite = intval($idSite);
+        }
+
+        $policy::setActiveStatus($idSite, $enforce);
+
+        return $enforce;
+    }
+
     private function savePurgeDataSettings($settings)
     {
         Piwik::checkUserHasSuperUserAccess();
