@@ -23,7 +23,7 @@ use Piwik\Plugins\CustomJsTracker\File;
 use Piwik\Plugins\FeatureFlags\FeatureFlagManager;
 use Piwik\Plugins\LanguagesManager\LanguagesManager;
 use Piwik\Plugins\LanguagesManager\API as APILanguagesManager;
-use Piwik\Plugins\PrivacyManager\FeatureFlags\ConfigIdRandomisation;
+use Piwik\Plugins\PrivacyManager\FeatureFlags\PrivacyCompliance;
 use Piwik\Plugins\SitesManager\SiteContentDetection\ConsentManagerDetectionAbstract;
 use Piwik\Plugins\SitesManager\SiteContentDetection\SiteContentDetectionAbstract;
 use Piwik\SiteContentDetector;
@@ -48,15 +48,11 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     /** @var SiteContentDetector */
     private $siteContentDetector;
 
-    /** @var FeatureFlagManager */
-    private $featureFlagManager;
-
-    public function __construct(ReferrerAnonymizer $referrerAnonymizer, SiteContentDetector $siteContentDetector, FeatureFlagManager $featureFlagManager)
+    public function __construct(ReferrerAnonymizer $referrerAnonymizer, SiteContentDetector $siteContentDetector)
     {
         parent::__construct();
         $this->referrerAnonymizer = $referrerAnonymizer;
         $this->siteContentDetector = $siteContentDetector;
-        $this->featureFlagManager = $featureFlagManager;
     }
 
     private function checkDataPurgeAdminSettingsIsEnabled()
@@ -154,7 +150,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
                 'description' => Piwik::translate('General_Recommended')],
             ['key' => '0',
                 'value' => Piwik::translate('PrivacyManager_DoNotTrack_Disable'),
-                'description' => Piwik::translate('General_NotRecommended')]
+                'description' => Piwik::translate('General_NotRecommended')],
         ];
 
         $dntChecker = new DoNotTrackHeaderChecker();
@@ -164,7 +160,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
         foreach ($languages as $language) {
             $languageOptions[] = [
                 'key' => $language['code'],
-                'value' => $language['name']
+                'value' => $language['name'],
             ];
         }
 
@@ -173,7 +169,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
             'currentLanguageCode' => LanguagesManager::getLanguageCodeForCurrentUser(),
             'languageOptions' => $languageOptions,
             'doNotTrackOptions' => $doNotTrackOptions,
-            'dntSupport' => $dntChecker->isActive()
+            'dntSupport' => $dntChecker->isActive(),
         ]);
     }
 
@@ -229,6 +225,21 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
         return $view->render();
     }
 
+    public function compliance(): string
+    {
+        Piwik::checkUserHasSuperUserAccess();
+        $featureFlagManager = StaticContainer::get(FeatureFlagManager::class);
+        if (!$featureFlagManager->isFeatureActive(PrivacyCompliance::class)) {
+            return '';
+        }
+
+        $view = new View('@PrivacyManager/compliance');
+        $view->language = LanguagesManager::getLanguageCodeForCurrentUser();
+        $this->setBasicVariablesView($view);
+
+        return $view->render();
+    }
+
     public function privacySettings()
     {
         Piwik::checkUserHasSuperUserAccess();
@@ -252,7 +263,6 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
             $view->dbUser = PiwikConfig::getInstance()->database['username'];
             $view->deactivateNonce = Nonce::getNonce(self::DEACTIVATE_DNT_NONCE);
             $view->activateNonce   = Nonce::getNonce(self::ACTIVATE_DNT_NONCE);
-            $view->configRandomisationFeatureFlag = $this->featureFlagManager->isFeatureActive(ConfigIdRandomisation::class);
 
             $view->maskLengthOptions = [
                 ['key' => '1',
@@ -266,7 +276,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
                       'description' => ''],
                 ['key' => '4',
                       'value' => Piwik::translate('PrivacyManager_AnonymizeIpMaskFully'),
-                      'description' => '']
+                      'description' => ''],
             ];
             $view->useAnonymizedIpForVisitEnrichmentOptions = [
                 ['key' => '1',
@@ -275,8 +285,8 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
                 [
                       'key' => '0',
                       'value' => Piwik::translate('General_No'),
-                      'description' => ''
-                ]
+                      'description' => '',
+                ],
             ];
             $view->scheduleDeletionOptions = [
                 ['key' => '1',
@@ -284,7 +294,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
                 ['key' => '7',
                       'value' => Piwik::translate('Intl_PeriodWeek')],
                 ['key' => '30',
-                      'value' => Piwik::translate('Intl_PeriodMonth')]
+                      'value' => Piwik::translate('Intl_PeriodMonth')],
             ];
             $view->referrerAnonymizationOptions = $this->referrerAnonymizer->getAvailableAnonymizationOptions();
         }
@@ -320,7 +330,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
 
         $formatter = new Formatter();
         $result = [
-            'currentSize' => $formatter->getPrettySizeFromBytes($totalBytes)
+            'currentSize' => $formatter->getPrettySizeFromBytes($totalBytes),
         ];
 
         // if the db size estimate feature is enabled, get the estimate
