@@ -10,8 +10,10 @@
 namespace Piwik\Plugins\UsersManager;
 
 use Piwik\Auth\Password;
+use Piwik\Request\AuthenticationToken;
 use Piwik\Common;
 use Piwik\Config\GeneralConfig;
+use Piwik\Container\StaticContainer;
 use Piwik\Date;
 use Piwik\Db;
 use Piwik\Option;
@@ -33,7 +35,7 @@ use Piwik\Validators\NotEmpty;
  * Existing Permissions are listed given a login via "getSitesAccessFromUser", or a website ID via "getUsersAccessFromSite",
  * or you can list all users and websites for a given permission via "getUsersSitesFromAccess". Permissions are set and updated
  * via the method "setUserAccess".
- * See also the documentation about <a href='http://piwik.org/docs/manage-users/' rel='noreferrer' target='_blank'>Managing Users</a> in Piwik.
+ * See also the documentation about <a href='https://matomo.org/docs/manage-users/' rel='noreferrer' target='_blank'>Managing Users</a> in Piwik.
  */
 class Model
 {
@@ -150,12 +152,12 @@ class Model
      * @param string $userLogin User that has to be valid
      *
      * @return array    The returned array has the format
-     *                    array(
-     *                        idsite1 => 'view',
-     *                        idsite2 => 'admin',
-     *                        idsite3 => 'view',
+     *                    [
+     *                        ['site' => 'idsite1', 'access' => 'view'],
+     *                        ['site' => 'idsite2', 'access' => 'admin'],
+     *                        ['site' => 'idsite3', 'access' => 'view'],
      *                        ...
-     *                    )
+     *                    [
      */
     public function getSitesAccessFromUser($userLogin)
     {
@@ -163,8 +165,8 @@ class Model
         $siteTable = Common::prefixTable('site');
 
         $sql = sprintf("SELECT access.idsite, access.access 
-    FROM %s access 
-    LEFT JOIN %s site 
+    FROM `%s` access 
+    LEFT JOIN `%s` site 
     ON access.idsite=site.idsite
      WHERE access.login = ? and site.idsite is not null", $accessTable, $siteTable);
         $db = $this->getDb();
@@ -189,9 +191,9 @@ class Model
     ) {
         $siteAccessFilter = new SiteAccessFilter($userLogin, $pattern, $access, $idSites);
 
-        list($joins, $bind) = $siteAccessFilter->getJoins('a');
+        [$joins, $bind] = $siteAccessFilter->getJoins('a');
 
-        list($where, $whereBind) = $siteAccessFilter->getWhere();
+        [$where, $whereBind] = $siteAccessFilter->getWhere();
         $bind = array_merge($bind, $whereBind);
 
         $limitSql = '';
@@ -211,7 +213,7 @@ class Model
         }
 
         $sql = 'SELECT s.idsite as idsite, s.name as site_name, GROUP_CONCAT(' . $selector . ' SEPARATOR "|") as access
-                  FROM ' . Common::prefixTable('access') . " a
+                  FROM `' . Common::prefixTable('access') . "` a
                 $joins
                 $where
               GROUP BY s.idsite
@@ -225,7 +227,7 @@ class Model
         }
 
         $sql = 'SELECT COUNT(DISTINCT s.idsite)
-                 FROM ' . Common::prefixTable('access') . " a
+                 FROM `' . Common::prefixTable('access') . "` a
                 $joins
                 $where";
 
@@ -238,12 +240,12 @@ class Model
     {
         $siteAccessFilter = new SiteAccessFilter($userLogin, $filter_search, $filter_access, $idSites);
 
-        list($joins, $bind) = $siteAccessFilter->getJoins('a');
+        [$joins, $bind] = $siteAccessFilter->getJoins('a');
 
-        list($where, $whereBind) = $siteAccessFilter->getWhere();
+        [$where, $whereBind] = $siteAccessFilter->getWhere();
         $bind = array_merge($bind, $whereBind);
 
-        $sql = 'SELECT s.idsite FROM ' . Common::prefixTable('access') . " a $joins $where";
+        $sql = 'SELECT s.idsite FROM `' . Common::prefixTable('access') . "` a $joins $where";
 
         $db = $this->getDb();
 
@@ -252,7 +254,7 @@ class Model
         return $sites;
     }
 
-    public function getUser($userLogin)
+    public function getUser($userLogin): array
     {
         $db = $this->getDb();
 
@@ -268,11 +270,17 @@ class Model
             }
         }
 
-        return reset($matchedUsers);
+        if (!count($matchedUsers)) {
+            return [];
+        }
+
+        return (array) reset($matchedUsers);
     }
 
-    public function hashTokenAuth($tokenAuth)
-    {
+    public function hashTokenAuth(
+        #[\SensitiveParameter]
+        $tokenAuth
+    ) {
         $salt = SettingsPiwik::getSalt();
         return hash(self::TOKEN_HASH_ALGO, $tokenAuth . $salt);
     }
@@ -337,6 +345,7 @@ class Model
      */
     public function addTokenAuth(
         $login,
+        #[\SensitiveParameter]
         $tokenAuth,
         $description,
         $dateCreated,
@@ -373,8 +382,10 @@ class Model
         return $db->lastInsertId();
     }
 
-    private function getTokenByTokenAuth($tokenAuth)
-    {
+    private function getTokenByTokenAuth(
+        #[\SensitiveParameter]
+        $tokenAuth
+    ) {
         $tokenAuth = $this->hashTokenAuth($tokenAuth);
         $db = $this->getDb();
 
@@ -397,7 +408,7 @@ class Model
     {
         return array(
           'sql'  => ' (date_expired is null or date_expired > ?)',
-          'bind' => array(Date::now()->getDatetime())
+          'bind' => array(Date::now()->getDatetime()),
         );
     }
 
@@ -410,8 +421,11 @@ class Model
      * @return array|bool               An array representing the token record, or null if not found
      * @throws \Exception
      */
-    private function getTokenByTokenAuthIfNotExpired(?string $tokenAuth, bool $isTokenSecured)
-    {
+    private function getTokenByTokenAuthIfNotExpired(
+        #[\SensitiveParameter]
+        ?string $tokenAuth,
+        bool $isTokenSecured
+    ) {
         // If the token wasn't provided via a secure mechanism and use of secure tokens is enforced globally
         // then don't attempt to find the token
         if (GeneralConfig::getConfigValue('only_allow_secure_auth_tokens') && !$isTokenSecured) {
@@ -517,8 +531,11 @@ class Model
         );
     }
 
-    public function setTokenAuthWasUsed($tokenAuth, $dateLastUsed)
-    {
+    public function setTokenAuthWasUsed(
+        #[\SensitiveParameter]
+        $tokenAuth,
+        $dateLastUsed
+    ) {
         $token = $this->getTokenByTokenAuth($tokenAuth);
         if (!empty($token)) {
             $lastUsage = !empty($token['last_used']) ? strtotime($token['last_used']) : 0;
@@ -531,11 +548,21 @@ class Model
             }
 
             $this->updateTokenAuthTable($token['idusertokenauth'], array(
-              'last_used' => $dateLastUsed
+              'last_used' => $dateLastUsed,
             ));
         }
     }
 
+    public function setRotationNotificationWasSentForToken(string $tokenId, string $tsRotation)
+    {
+        $this->updateTokenAuthTable($tokenId, ['ts_rotation_notified' => $tsRotation]);
+    }
+
+    public function setExpirationWarningNotificationWasSentForToken(string $tokenId, string $tsExpirationWarning)
+    {
+        $this->updateTokenAuthTable($tokenId, ['ts_expiration_warning_notified' => $tsExpirationWarning]);
+    }
+
     private function updateTokenAuthTable($idTokenAuth, $fields)
     {
         $set = array();
@@ -561,8 +588,10 @@ class Model
     }
 
 
-    public function getUserByInviteToken($tokenAuth)
-    {
+    public function getUserByInviteToken(
+        #[\SensitiveParameter]
+        $tokenAuth
+    ) {
         $token = $this->hashTokenAuth($tokenAuth);
         if (!empty($token)) {
             $db = $this->getDb();
@@ -578,14 +607,18 @@ class Model
      * @return array|null
      * @throws \Exception
      */
-    public function getUserByTokenAuth(?string $tokenAuth): ?array
-    {
+    public function getUserByTokenAuth(
+        #[\SensitiveParameter]
+        ?string $tokenAuth
+    ): ?array {
         if ($tokenAuth === 'anonymous') {
             $row = $this->getUser('anonymous');
-            return (is_array($row) ? $row : null);
+            return (!empty($row) ? $row : null);
         }
 
-        $token = $this->getTokenByTokenAuthIfNotExpired($tokenAuth, \Piwik\API\Request::isTokenAuthProvidedSecurely());
+        $isTokenProvidedSecurely = StaticContainer::get(AuthenticationToken::class)->wasTokenAuthProvidedSecurely();
+
+        $token = $this->getTokenByTokenAuthIfNotExpired($tokenAuth, $isTokenProvidedSecurely);
         if (!empty($token)) {
             $db = $this->getDb();
             $row = $db->fetchRow("SELECT * FROM " . $this->userTable . " WHERE `login` = ?", $token['login']);
@@ -601,8 +634,13 @@ class Model
      * @param $email
      * @param $dateRegistered
      */
-    public function addUser($userLogin, $hashedPassword, $email, $dateRegistered)
-    {
+    public function addUser(
+        $userLogin,
+        #[\SensitiveParameter]
+        $hashedPassword,
+        $email,
+        $dateRegistered
+    ) {
         $user = array(
           'login'                => $userLogin,
           'password'             => $hashedPassword,
@@ -622,7 +660,7 @@ class Model
     {
         $this->updateUserFields($userLogin, [
           'invite_token'      => $this->hashTokenAuth($token),
-          'invite_expired_at' => Date::now()->addDay($expiryInDays)->getDatetime()
+          'invite_expired_at' => Date::now()->addDay($expiryInDays)->getDatetime(),
         ]);
     }
 
@@ -637,7 +675,7 @@ class Model
     public function setSuperUserAccess($userLogin, $hasSuperUserAccess)
     {
         $this->updateUserFields($userLogin, array(
-          'superuser_access' => $hasSuperUserAccess ? 1 : 0
+          'superuser_access' => $hasSuperUserAccess ? 1 : 0,
         ));
     }
 
@@ -673,8 +711,12 @@ class Model
         return $users;
     }
 
-    public function updateUser($userLogin, $hashedPassword, $email)
-    {
+    public function updateUser(
+        $userLogin,
+        #[\SensitiveParameter]
+        $hashedPassword,
+        $email
+    ) {
         $fields = array(
           'email' => $email,
         );
@@ -801,8 +843,8 @@ class Model
     ) {
         $filter = new UserTableFilter($access, $idSite, $pattern, $status, $logins);
 
-        list($joins, $bind) = $filter->getJoins('u');
-        list($where, $whereBind) = $filter->getWhere();
+        [$joins, $bind] = $filter->getJoins('u');
+        [$where, $whereBind] = $filter->getWhere();
 
         $bind = array_merge($bind, $whereBind);
 
@@ -817,7 +859,7 @@ class Model
         }
 
         $sql = 'SELECT u.*, GROUP_CONCAT(a.access SEPARATOR "|") as access
-                  FROM ' . $this->userTable . " u
+                  FROM `' . $this->userTable . "` u
                 $joins
                 $where
               GROUP BY u.login
@@ -832,7 +874,7 @@ class Model
         }
 
         $sql = 'SELECT COUNT(DISTINCT u.login)
-                  FROM ' . $this->userTable . " u
+                  FROM `' . $this->userTable . "` u
                 $joins
                 $where";
 
@@ -854,7 +896,7 @@ class Model
     {
         $idSites = array_map('intval', $idSites);
 
-        $loginSql = 'SELECT DISTINCT ia.login FROM ' . Common::prefixTable('access') . ' ia WHERE ia.idsite IN ('
+        $loginSql = 'SELECT DISTINCT ia.login FROM `' . Common::prefixTable('access') . '` ia WHERE ia.idsite IN ('
           . implode(',', $idSites) . ')';
 
         $logins = \Piwik\Db::fetchAll($loginSql);
@@ -870,4 +912,135 @@ class Model
         $count = (int) $db->fetchOne($sql, $bind);
         return $count > 0;
     }
+
+    public function getLastSeenTimestamp(string $userLogin): ?int
+    {
+        $db = $this->getDb();
+        $sql = "SELECT ts_last_seen FROM " . $this->userTable . " WHERE login = ?";
+        $bind = [$userLogin];
+        $dt = $db->fetchOne($sql, $bind);
+        if ($dt) {
+            return Date::factory($dt)->getTimestamp();
+        }
+        return null;
+    }
+
+    public function getLastSeenTimestampForAllSeenUsers(): array
+    {
+        $db = $this->getDb();
+        $sql = "
+            SELECT
+                login,
+                UNIX_TIMESTAMP(ts_last_seen) as last_seen
+            FROM " . $this->userTable . " 
+            WHERE ts_last_seen IS NOT NULL
+        ";
+        $rows = $db->fetchAll($sql);
+        $users = [];
+        if ($rows) {
+            foreach ($rows as $row) {
+                $users[$row['login']] = $row['last_seen'];
+            }
+        }
+        return $users;
+    }
+
+    public function setLastSeenDatetime(string $userLogin, string $datetime): void
+    {
+        $db = $this->getDb();
+        $sql = "UPDATE `" . $this->userTable . "` SET `ts_last_seen` = ? WHERE login = ?";
+        $bind = [$datetime, $userLogin];
+        $db->query($sql, $bind);
+    }
+
+    public function getUsersWithoutActivityForDays(int $days = 180): array
+    {
+        $db = $this->getDb();
+        $sql = "
+            SELECT
+                u.login,
+                COALESCE(u.ts_last_seen, u.date_registered) as ts_last_seen,
+                MAX(COALESCE(t.last_used, t.date_created)) AS ts_last_token_activity
+            FROM " . $this->userTable . " u
+            LEFT JOIN " . $this->tokenTable . " t ON u.login = t.login
+            WHERE 
+                u.login != ? AND
+                u.ts_inactivity_notified IS NULL
+            GROUP BY
+                u.login,
+                u.email,
+                u.ts_last_seen,
+                u.date_registered
+            HAVING COALESCE(u.ts_last_seen, u.date_registered) < (? - INTERVAL ? DAY)
+            ORDER BY u.login;
+        ";
+        $bind = ['anonymous', Date::factory('now')->getDatetime(), $days];
+        return $db->fetchAll($sql, $bind);
+    }
+
+    public function getTokensRequiringRotation(string $periodThreshold): array
+    {
+        $db = $this->getDb();
+        // Join on user table is done to ensure we only fetch tokens where the user still exists
+        $sql = "
+            SELECT
+                t.login,
+                t.idusertokenauth as tokenId,
+                t.description as tokenName,
+                t.date_created as tokenDate
+            FROM " . Common::prefixTable('user_token_auth') . " t
+            JOIN  " . Common::prefixTable('user') . " u ON t.login = u.login
+            WHERE
+                (t.date_expired IS NULL OR t.date_expired > ?) AND
+                (t.date_created <= ?) AND
+                t.ts_rotation_notified IS NULL AND
+                t.system_token = 0 AND
+                t.login != ?
+        ";
+
+        return $db->fetchAll($sql, [
+            Date::factory('now')->getDatetime(),
+            $periodThreshold,
+            'anonymous',
+        ]);
+    }
+
+    public function getTokensExpiringSoon(string $periodThreshold): array
+    {
+        $db = $this->getDb();
+        // Join on user table is done to ensure we only fetch tokens where the user still exists
+        $sql = "
+            SELECT
+                t.login,
+                t.idusertokenauth as tokenId,
+                t.description as tokenName,
+                t.date_expired as tokenDate
+            FROM " . Common::prefixTable('user_token_auth') . " t
+            JOIN  " . Common::prefixTable('user') . " u ON t.login = u.login
+            WHERE
+                t.date_expired IS NOT NULL AND
+                (t.date_created <= ?) AND
+                (t.date_expired > ?) AND
+                (t.date_expired <= ?) AND
+                t.ts_expiration_warning_notified IS NULL AND
+                t.system_token = 0 AND
+                t.login != ?
+        ";
+
+        $now = Date::factory('now')->getDatetime();
+
+        return $db->fetchAll($sql, [
+            $now,
+            $now,
+            $periodThreshold,
+            'anonymous',
+        ]);
+    }
+
+    public function setInactiveUserNotificationWasSentForUsers(array $users, string $dtNotified): void
+    {
+        foreach ($users as $user) {
+            $this->updateUserFields($user['login'], ['ts_inactivity_notified' => $dtNotified]);
+        }
+    }
 }
